/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/


/******************************************************************************
 * - Nom du fichier : test10.c
 *
 * - Description : ecriture de champs de resultats MED 
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#define USER_INTERLACE MED_FULL_INTERLACE
/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - ecriture d'un champ reel
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  char maa[MED_TAILLE_NOM+1]= "maa1";
  med_int mdim = 3;
  char comp1[2*MED_TAILLE_PNOM+1] = "comp1   comp2   ";
  char comp2[3*MED_TAILLE_PNOM+1] = "comp1   comp2   comp3   ";
  char unit1[2*MED_TAILLE_PNOM+1] = "unit1   unit2   ";
  char unit2[3*MED_TAILLE_PNOM+1] = "unit1   unit2   unit3   ";
  char nomcha1[MED_TAILLE_NOM+1]="champ reel";
  char nomcha2[MED_TAILLE_NOM+1]="champ entier";
  med_int ncomp1  = 2, ncomp2 = 3; 
  med_int ngauss1 = 2, ngauss2 = 1; 
  med_int nval1 = 3*2; /*3 valeurs et 2 points de gauss par valeur */
  med_int nval2 = 5;   /*5 valeurs et pas de  points de gauss  */
  med_float valr1[3*2*2]  = {0.0,1.0,2.0,3.0, 10.0,11.0,12.0,13.0, 20.0,21.0,22.0,23.0};  /* 2 composantes*/
  med_int   valr2[5*3  ]  = {0,1,2, 10,11,12, 20,21,22, 30,31,32, 40,41,42};              /* 3 composantes*/
  med_float valr1p[2*2*2] = {                 10.0,11.0,12.0,13.0, 20.0,21.0,22.0,23.0};  /* 2 composantes*/
  med_int   valr2p[3*3  ] = {0,1,2,           20,21,22,           40,41,42};              /* 3 composantes*/
  med_int profil1[2] = { 2, 3 };
  med_int profil2[3] = { 1, 3, 5 };

  /* ouverture du fichier */
  if ((fid = MEDouvrir("test10.med",MED_REMP)) < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);
  
  /* creation d'un maillage de dimension 3*/
  if (ret == 0)
    ret = MEDmaaCr(fid,maa,3);
  printf("%d\n",ret);
  
  /* creation du champ n1 */
  if (ret == 0)
    ret = MEDchampCr(fid,nomcha1,MED_REEL64,comp1,unit1,ncomp1);
  printf("%d\n",ret);
  
  /* creation du champ n2 */
  if (ret == 0)
    ret = MEDchampCr(fid,nomcha2,MED_INT32,comp2,unit2,ncomp2);
  printf("%d\n",ret);


  /* ecriture du champ n1*/
  /* enregistre uniquement les composantes n2 de valr1, et n'utilise ni pas de temps ni n d'ordre*/
  if (ret == 0)
    ret = MEDchampEcr(fid,maa,nomcha1,(unsigned char*)valr1,USER_INTERLACE,nval1,ngauss1,
		      2,MED_NOPFL,MED_ECRI,MED_MAILLE,MED_TRIA3,MED_NOPDT,"",0.0,MED_NONOR);
  
  printf("%d\n",ret);

  /* cet appel en mode MED_REMP complte le champ prcdent en enregistrant les composantes n1 */
  if (ret == 0)
    ret = MEDchampEcr(fid,maa,nomcha1,(unsigned char*)valr1,USER_INTERLACE,nval1,ngauss1,
		      1,MED_NOPFL,MED_REMP,MED_MAILLE,MED_TRIA3,MED_NOPDT,"",0.0,MED_NONOR);
  
  printf("%d\n",ret);

  if (ret == 0)
    /* enregistre uniquement les composantes n2 de valr1, au pas de temps n1(5.5), n'utilise pas de nd'ordre*/
   ret = MEDchampEcr(fid,maa,nomcha1,(unsigned char*)valr1,USER_INTERLACE,nval1,ngauss1,
		      2,MED_NOPFL,MED_ECRI,MED_MAILLE,MED_TRIA3,1,"ms",5.5,MED_NONOR);
  
  printf("%d\n",ret);


  if (ret == 0)
    /* enregistre uniquement les composantes n1 de valr1, au pas de temps n1(5.5), et nd'itration n2*/
    ret = MEDchampEcr(fid,maa,nomcha1,(unsigned char*)valr1,USER_INTERLACE,nval1,ngauss1,
		      1,MED_NOPFL,MED_ECRI,MED_MAILLE,MED_TRIA3,1,"ms",5.5,2);
  
  printf("%d\n",ret);

  /* Creation d'un profil (selection  du deuxieme lment de valr1) */
  if (ret == 0)
    ret =  MEDprofilEcr(fid,profil1,1,"PROFIL(champ(1))"); /* On n'utilise que la premire valeur (2) du profil */
  printf("%d\n",ret);

  if (ret == 0)
    /* enregistre toutes les composantes du deuxime lment de valr1 (premier lment en stockage compact de valr1p),
       au pas de temps n2(5.6), et nd'itration n2*/
    ret = MEDchampEcr(fid,maa,nomcha1,(unsigned char*)valr1p,USER_INTERLACE,nval1,ngauss1,
		      MED_ALL,"PROFIL(champ(1))",MED_ECRI,MED_MAILLE,MED_TRIA3,2,"ms",5.6,2);
  printf("%d\n",ret);
  
  if (ret == 0)
    /* enregistre la composante n2 du deuxime lment de valr1, au pas de temps n2(5.7), et nd'itration n2*/
   ret = MEDchampEcr(fid,maa,nomcha1,(unsigned char*)valr1p,USER_INTERLACE,nval1,ngauss1,
		      2,"PROFIL(champ(1))",MED_ECRI,MED_MAILLE,MED_TRIA3,3,"ms",5.7,2);
  printf("%d\n",ret);

  /* ecriture du champ n 2 */
  /* TESTER EGALEMENT EN MODE FULL_INTERLACE EN MODIFIANT LA SIGNATURE DE LA ROUTINE */

  if (ret == 0)
    /* enregistre la composante n1 des lments de valr2, et n'utilise ni pas de temps ni n d'ordre */
    ret = MEDchampEcr(fid,maa,nomcha2,(unsigned char*)valr2,USER_INTERLACE,nval2,ngauss2,
                      1,MED_NOPFL,MED_ECRI,MED_ARETE,MED_SEG2,MED_NOPDT,"",0.0,MED_NONOR);
  printf("%d\n",ret);
 
  if (ret == 0)
    /* enregistre la composante n2 des lments de valr2, et n'utilise ni pas de temps ni n d'ordre */
    /*        pour des raisons de compltude des tests on change le type d'lment (aucun sens phys.))*/
    ret = MEDchampEcr(fid,maa,nomcha2,(unsigned char*)valr2,USER_INTERLACE,nval2,ngauss2,
                      2,MED_NOPFL,MED_ECRI,MED_NOEUD,0,MED_NOPDT,"",0.0,MED_NONOR); 
  printf("%d\n",ret);

  if (ret == 0)
    /* enregistre la composante n3 des lments de valr2, et n'utilise ni pas de temps ni n d'ordre */
    /*        pour des raisons de compltude des tests on change le type d'lment (aucun sens phys.))*/
    ret = MEDchampEcr(fid,maa,nomcha2,(unsigned char*)valr2,USER_INTERLACE,nval2,ngauss2,
                      3,MED_NOPFL,MED_ECRI,MED_FACE,MED_TRIA3,MED_NOPDT,"",0.0,MED_NONOR); 
  printf("%d\n",ret);

  /* Creation d'un profil (selection  des lments 1,3,5 de valr2) */
  if (ret == 0)
    ret =  MEDprofilEcr(fid,profil2,3,"PROFIL(champ2)"); /* On utilise les trois valeurs du profil */
  printf("%d\n",ret);
  
  if (ret == 0)
    /* enregistre la composante n3 des lments du profil2 de valr2, et n'utilise ni pas de temps ni n d'ordre */
    ret = MEDchampEcr(fid,maa,nomcha2,(unsigned char*)valr2p,USER_INTERLACE,nval2,ngauss2,
                      3,"PROFIL(champ2)",MED_ECRI,MED_MAILLE,MED_TRIA3,MED_NOPDT,"",0.0,MED_NONOR); 
  printf("%d\n",ret);
  
  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);

  return 0;
}




