/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/


/******************************************************************************
 * - Nom du fichier : test4.c
 *
 * - Description : ecriture des objets MED relatifs aux noeuds
 *                 a l'aide des routines de bas niveau 
 *                 MED
 *
 *****************************************************************************/

#include <med.h>
#include <string.h>

/******************************************************************************
 *    - creation d'un fichier MED
 *    - ecriture des noeuds : coordonnees en mode MED_FULL_INTERLACE,
 *                            noms,numeros,numeros de familles
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  /* la dimension du maillage */
  med_int mdim = 2;
  /* nom du maillage de longueur maxi MED_TAILLE_NOM */
  char maa[MED_TAILLE_NOM+1] = "maa1";
  /* le nombre de noeuds */
  med_int nnoe = 4;
  /* table des coordonnees  
     profil : (dimension * nombre de noeuds) */
  med_float coo[8] = {0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0};
  /* tables des noms et des unites des coordonnees 
     profil : (dimension*MED_TAILLE_PNOM+1) */
  char nomcoo[2*MED_TAILLE_PNOM+1] = "x       y      ";
  char unicoo[2*MED_TAILLE_PNOM+1] = "cm      cm     ";
  /* tables des noms, numeros, numeros de familles des noeuds
     autant d'elements que de noeuds - les noms ont pout longueur
     MED_TAILLE_PNOM */
  char nomnoe[4*MED_TAILLE_PNOM+1] = "nom1    nom2    nom3    nom4";
  med_int numnoe[4] = {1,2,3,4};
  med_int nufano[4] = {0,1,2,2};; 

  fid = MEDouvrir("test4.med",MED_REMP);
  if (fid < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);

  /* creation du maillage maa de dimension 2 */
  if (ret == 0)
    ret = MEDmaaCr(fid,maa,mdim);
  printf("%d\n",ret);

  /* ecriture des coo en mode MED_FULL_INTERLACE :(X1,Y1, X2,Y2, X3,Y3, ...) 
     dans un repere cartesien */
  if (ret == 0)
    ret = MEDcoordEcr(fid,maa,mdim,coo,MED_FULL_INTERLACE,nnoe,MED_ECRI,
		      MED_CART,nomcoo,unicoo);

  /* ecriture des noms des noeuds (optionnel dans un fichier MED) */
  if (ret == 0)
    ret = MEDnomEcr(fid,maa,nomnoe,nnoe,MED_ECRI,MED_NOEUD,0);
  printf("%d\n",ret);

  /* ecriture des numeros des noeuds (optionnel dans un fichier MED) */
  if (ret == 0)
    ret = MEDnumEcr(fid,maa,numnoe,nnoe,MED_ECRI,MED_NOEUD,0);
  printf("%d\n",ret);

  /* ecriture des numeros de familles des noeuds */	      
  if (ret == 0)
    ret = MEDfamEcr(fid,maa,nufano,nnoe,MED_ECRI,MED_NOEUD,0);
  printf("%d\n",ret);

  ret = MEDfermer(fid);
  printf("%d\n",ret);
  
  return 0;
}




