/*************************************************************************
* COPYRIGHT (C) 1999 - 2002  EDF R&D
* THIS LIBRARY IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
* IT UNDER THE TERMS OF THE GNU LESSER GENERAL PUBLIC LICENSE 
* AS PUBLISHED BY THE FREE SOFTWARE FOUNDATION; 
* EITHER VERSION 2.1 OF THE LICENSE, OR (AT YOUR OPTION) ANY LATER VERSION.
*  
* THIS LIBRARY IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
* WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
* MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
* LESSER GENERAL PUBLIC LICENSE FOR MORE DETAILS.
*
* YOU SHOULD HAVE RECEIVED A COPY OF THE GNU LESSER GENERAL PUBLIC LICENSE
* ALONG WITH THIS LIBRARY; IF NOT, WRITE TO THE FREE SOFTWARE FOUNDATION,
* INC., 59 TEMPLE PLACE, SUITE 330, BOSTON, MA 02111-1307 USA
*
*************************************************************************/

/******************************************************************************
 * - Nom du fichier : test8.c
 *
 * - Description : ecriture des familles d'un maillage MED 
 *                 via les routines de bas niveau
 *
 *****************************************************************************/

#include <med.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/******************************************************************************
 * Description :
 *    - ouverture du fichier
 *    - ecriture des familles
 *    - fermeture du fichier
 *****************************************************************************/

int main (int argc, char **argv)
{
  med_err ret;
  med_idt fid;
  char maa[MED_TAILLE_NOM+1] ="maa1";
  med_int mdim = 2;
  char nomfam[MED_TAILLE_NOM+1];
  med_int numfam;
  char attdes[MED_TAILLE_DESC+1];
  med_int natt;
  med_int attide;
  med_int attval;
  med_int ngro;
  char gro[MED_TAILLE_LNOM+1];
  int i;
  int nfame = 3; 
  int nfamn = 2;

  /* ouverture du fichier */
  if ((fid = MEDouvrir("test8.med",MED_REMP)) < 0)
    ret = -1;
  else
    ret = 0;
  printf("%d\n",ret);

  /* creation du maillage */
  if (ret == 0)
    ret = MEDmaaCr(fid,maa,2);
  printf("%d\n",ret);

  /* ecriture des familles */
  /* Conventions :
     - toujours creer une famille de numero 0 ne comportant aucun attribut
       ni groupe (famille de reference pour les noeuds ou les elements
       qui ne sont rattaches a aucun groupe ni attribut)
     - les numeros de familles de noeuds sont > 0
     - les numeros de familles des elements sont < 0
     - rien d'imposer sur les noms de familles
   */ 

  /* la famille 0 */
  if (ret == 0)
    {
      strcpy(nomfam,"FAMILLE_0");
      numfam = 0;
      ret = MEDfamCr(fid,maa,nomfam,numfam,&attide,&attval,attdes,0,
		     gro,0);
    }
  printf("%d \n",ret);

  /* on cree pour correspondre aux cas tests precedents, 3 familles
     d'elements (-1,-2,-3) et deux familles de noeuds (1,2) */
  if (ret == 0)
    {
      nfame = 3;
      for (i=0;i<nfame;i++)
	{
	  if (ret == 0)
	    {
	      strcpy(nomfam,"FAMILLE_ELEMENT_");
	      numfam = -(i+1);
	      sprintf(nomfam,"%s%d",nomfam,-numfam);
	      attide = 1;
	      attval = numfam*100;
              natt = 1;
	      strcpy(attdes,"description attribut");
              strcpy(gro,"groupe1");
	      ngro = 1;
              printf("%s - %d - %d - %d - %d \n",nomfam,numfam,attide,attval,
		     ngro);
	      ret = MEDfamCr(fid,maa,nomfam,numfam,&attide,&attval,attdes,
			     natt,gro,ngro);
              printf("MEDfamCr : %d\n",ret);
	    }
	}
    }
  
    if (ret == 0)
    {
      nfamn = 2;
      for (i=0;i<nfamn;i++)
	{
	  if(ret == 0)
	    {
	      strcpy(nomfam,"FAMILLE_NOEUD_");
	      numfam = i+1;
	      sprintf(nomfam,"%s%d",nomfam,numfam);
	      attide = 1;
	      attval = numfam*100;
              natt = 1;
	      strcpy(attdes,"description attribut");
              strcpy(gro,"groupe1");
	      ngro = 1;
	      ret = MEDfamCr(fid,maa,nomfam,numfam,&attide,&attval,attdes,
			     natt,gro,ngro);
              printf("MEDfamCr : %d\n",ret);
	    }
	}
    }


  /* fermeture du fichier */
  ret = MEDfermer(fid);
  printf("%d\n",ret);

  return 0;
}




